<?php
/**
 * Rustic State functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 */


//  CONSTANTS
//
//  Global variable of pages num
define('RUSTIC_STATE_PAGES_NUM', get_option( 'posts_per_page' ) );

/**
 * Load custom colors.
 */
require get_template_directory() . '/inc/custom-colors.php';

function rustic_state_fonts_url($font) {
    $font_url = '';

    /*
    Translators: If there are characters in your language that are not supported
    by chosen font(s), translate this to 'off'. Do not translate into your own language.
     */
    if ( 'off' !== _x( 'on', 'Google font: on or off', 'rustic-state' ) ) {
      $font_url = $font;
    }
    return $font_url;
}

if ( ! function_exists( 'rustic_state_setup' ) ) :
	function rustic_state_setup() {

		/**
		* Proper way to enqueue scripts and styles.
		*/
		function rustic_state_scripts_loader() {
			$font_primary = 'https://fonts.googleapis.com/css?family=Inconsolata:400,700&amp;subset=latin-ext';
			$font_secondary = 'https://fonts.googleapis.com/css?family=IM+Fell+DW+Pica:400,400i&amp;subset=latin-ext';

			if (get_option("Font_primary_url")) {
				$font_primary = esc_url(get_option("Font_primary_url"));
			}

			if (get_option("Font_secondary_url")) {
				$font_secondary = esc_url(get_option("Font_secondary_url"));
			} 

			wp_enqueue_style( 'rustic-state-vendor-css', get_template_directory_uri() . '/styles/vendor.min.css', array(), '1.0.1');
			wp_enqueue_style( 'rustic-state-css-main', get_template_directory_uri() . '/styles/style.css', array(), '1.0.1');
			wp_enqueue_style( 'rustic-state-css', get_template_directory_uri() . '/style.css', array(), '1.0.1');
			wp_add_inline_style( 'rustic-state-css-main', rustic_state_get_custom_css() );

			wp_enqueue_style( 'rustic-state-google-fonts-serif', rustic_state_fonts_url($font_primary), array(), '1.0.0');
			wp_enqueue_style( 'rustic-state-google-fonts-sans-serif', rustic_state_fonts_url($font_secondary), array(), '1.0.0');

			wp_enqueue_script( 'rustic-state-main-js', get_template_directory_uri() . '/js/main.js', array('jquery'), '1.0.1', true );

			if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
				wp_enqueue_script( 'comment-reply' );
			}
		}
		add_action( 'wp_enqueue_scripts', 'rustic_state_scripts_loader' );

		/*
		 * Page formats
		 */
		add_theme_support( 'post-formats', array('') );

		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Rustic State, use a find and replace
		 * to change 'rustic-state' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'rustic-state', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails');

		set_post_thumbnail_size( 1800, 900 );
		add_image_size( 'rustic-state-grid-thumbnail', 320, 180, true );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'primary' => esc_html__( 'Menu Primary', 'rustic-state' ),
			'top' => esc_html__( 'Menu Top', 'rustic-state' )
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support('html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		));


    /**
     * Register widgets area in footer
     */

    function rustic_state_footer_widget_init_left() {
       register_sidebar( array(
           'name'          => esc_html__( 'Footer column left', 'rustic-state' ),
           'id'            => 'footer-1',
           'description'   => esc_html__( 'The left column in the footer.', 'rustic-state' ),
           'before_widget' => '<section id="%1$s" class="widget %2$s">',
           'after_widget'  => '</section>',
           'before_title'  => '<h2 class="widget-title">',
           'after_title'   => '</h2>',
       ) );
    }
    add_action( 'widgets_init', 'rustic_state_footer_widget_init_left' );


    function rustic_state_footer_widget_init_middle() {
       register_sidebar( array(
           'name'          => esc_html__( 'Footer column middle', 'rustic-state' ),
           'id'            => 'footer-2',
           'description'   => esc_html__( 'The middle column in the footer.', 'rustic-state' ),
           'before_widget' => '<section id="%1$s" class="widget %2$s">',
           'after_widget'  => '</section>',
           'before_title'  => '<h2 class="widget-title">',
           'after_title'   => '</h2>',
       ) );
    }
    add_action( 'widgets_init', 'rustic_state_footer_widget_init_middle' );


    function rustic_state_footer_widget_init_right() {
       register_sidebar( array(
           'name'          => esc_html__( 'Footer column right', 'rustic-state' ),
           'id'            => 'footer-3',
           'description'   => esc_html__( 'The right column in the footer.', 'rustic-state' ),
           'before_widget' => '<section id="%1$s" class="widget %2$s">',
           'after_widget'  => '</section>',
           'before_title'  => '<h2 class="widget-title">',
           'after_title'   => '</h2>',
       ) );
    }
    add_action( 'widgets_init', 'rustic_state_footer_widget_init_right' );
	}
endif;
add_action( 'after_setup_theme', 'rustic_state_setup' );


/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function rustic_state_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'rustic_state_content_width', 640 );
}
add_action( 'after_setup_theme', 'rustic_state_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function rustic_state_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'rustic-state' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'rustic-state' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'rustic_state_widgets_init' );

// Add callback for custom TinyMCE editor stylesheets.
add_editor_style();

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Helpers compatibility file.
 */
require get_template_directory() . '/inc/helpers.php';

/**
 * Load popular posts
 */
require get_template_directory() . '/inc/popular-posts.php';

/**
 * Load TGM compatibility file.
 */
require get_template_directory() . '/inc/tgm.php';


/**
 * Load widgets
 */
require get_template_directory() . '/inc/widgets/Recent_posts_widget.php';
require get_template_directory() . '/inc/widgets/Popular_posts_widget.php';
require get_template_directory() . '/inc/widgets/Banner_upload_widget.php';
