<?php
/**
 * The header for our theme.
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package Eppe
 */
?>

<!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
  <meta charset="<?php bloginfo( 'charset' ); ?>">
  <meta http-equiv="x-ua-compatible" content="ie=edge">
  <meta name="viewport" content="width=device-width, initial-scale=1">
  <meta name="description" content="<?php bloginfo('description'); ?>">

  <!-- Pingback -->
  <link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">

  <?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>

	<div class="nav-mobile">
		<div class="hamburger-mobile">
			<i class="fa fa-bars" aria-hidden="true"></i>
		</div>
		<!-- /.hamburger -->

		<?php
      if(has_nav_menu('primary')) {
        wp_nav_menu( array(
    			'container_class' => '',
    			'menu_class' => 'nav-mobile__list',
    			'theme_location' => 'primary',
    			'depth' => 2
    		));
      }
    ?>
	</div>
	<!-- /.nav-mobile -->


<?php if(get_option("RS_topnav-upload")): ?>
  <div id="page" class="site" style="background-image: url('<?php echo esc_url(get_option("RS_topnav-upload")) ?>')">
<?php else: ?>
  <div id="page" class="site">
<?php endif ?>

    <?php
      if(has_nav_menu('top')) {
        wp_nav_menu(array(
          'container_class' => 'top-nav-container',
          'menu_class' => 'top-nav',
          'theme_location' => 'top',
          'depth' => 1
        ));
      }
    ?>

    <div class="top-nav-right">
      <form role="search" method="get" id="searchform" class="search-form" action="<?php echo esc_url( home_url( '/' ) ); ?>">
        <div class="pos-absolute">
          <input type="text" value="<?php echo get_search_query(); ?>" class="input-absolute" name="s" id="search" placeholder="<?php echo esc_html__('search', 'rustic-state') ?>" />
        </div>
      </form>

      <?php
  		 	if (
  					get_option('RS_social-facebook') ||
  					get_option('RS_social-twitter') ||
  					get_option('RS_social-google') ||
  					get_option('RS_social-pinterest') ||
  					get_option('RS_social-instagram') ||
  					get_option('RS_social-youtube')
  				):
  		?>
        <div class="social-top-nav">
          <?php if (get_option('RS_social-facebook')): ?>
            <a href="<?php echo esc_url(get_option('RS_social-facebook')) ?>"><i class="fa fa-facebook"></i></a>
          <?php endif; ?>

          <?php if (get_option('RS_social-twitter')): ?>
            <a href="<?php echo esc_url(get_option('RS_social-twitter')) ?>"><i class="fa fa-twitter"></i></a>
          <?php endif; ?>

          <?php if (get_option('RS_social-google')): ?>
            <a href="<?php echo esc_url(get_option('RS_social-google')) ?>"><i class="fa fa-google"></i></a>
          <?php endif; ?>

          <?php if (get_option('RS_social-pinterest')): ?>
            <a href="<?php echo esc_url(get_option('RS_social-pinterest')) ?>"><i class="fa fa-pinterest-p"></i></a>
          <?php endif; ?>

          <?php if (get_option('RS_social-instagram')): ?>
            <a href="<?php echo esc_url(get_option('RS_social-instagram')) ?>"><i class="fa fa-instagram"></i></a>
          <?php endif; ?>

          <?php if (get_option('RS_social-youtube')): ?>
            <a href="<?php echo esc_url(get_option('RS_social-youtube')) ?>"><i class="fa fa-youtube"></i></a>
          <?php endif; ?>
        </div>
      <?php endif ?>

    </div>

  </div><!-- #page -->


	<div class="container">
		<div class="row">
			<div class="col-12">

				<div class="text-center">
          <div class="hamburger">
  					<i class="fa fa-bars" aria-hidden="true"></i>
  				</div>
				</div>
				<!-- /.hamburger -->

				<div class="text-center">
					<div class="logo">

						<?php if( get_header_image() ) : ?>
							<a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home" class="logo-url">
								<img src="<?php header_image(); ?>" width="<?php echo esc_attr( get_custom_header()->width ); ?>" height="<?php echo esc_attr( get_custom_header()->height ); ?>" alt="<?php echo esc_html__('Logo', 'rustic-state') ?>" class="logo-img">
							</a>
						<?php else: ?>
							<h1 class="logo-big-title"><a href="<?php echo esc_url(home_url()) ?>"><?php bloginfo() ?></a></h1>
						<?php endif ?>

            <?php
              if(has_nav_menu('primary')) {
                wp_nav_menu( array(
            			'container_class' => 'nav',
            			'menu_class' => 'nav__list',
            			'theme_location' => 'primary',
            			'depth' => 2
            		));
              }
            ?>

					</div>
				</div>


			</div>
		</div>
	</div>
	<!-- /.container -->
