<?php

add_theme_support('custom-background', apply_filters('rustic_state_custom_background_args', array(
	'default-color' => 'ffffff',
	'default-image' => '',
)));


/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function rustic_state_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';

	// Set up the WordPress core custom background feature.

	//  =============================
	//  = Fonts family
	//  =============================
	$wp_customize->add_section('RS_fonts-section', array(
		'title'   	 		=> esc_html__('Google Fonts', 'rustic-state'),
		'description' 	=> '',
		'priority'  		=> 0,
	));

	//  Sans-serif
	$wp_customize->add_setting('Font_primary_url', array(
		'default'    => 'https://fonts.googleapis.com/css?family=Inconsolata:400,700',
		'capability' => 'edit_theme_options',
		'type'       => 'option',
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control('Font_primary_url', array(
		'label'      => esc_html__('The text font family URL', 'rustic-state'),
		'section'    => 'RS_fonts-section',
		'settings'   => 'Font_primary_url',
		'description' => esc_html__('Example: "https://fonts.googleapis.com/css?family=Inconsolata:400,700"', 'rustic-state'),
	));

	$wp_customize->add_setting('Font_primary_name', array(
		'default'    => 'Inconsolata',
		'capability' => 'edit_theme_options',
		'type'       => 'option',
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control('Font_primary_name', array(
		'label'      => esc_html__('The text font family name', 'rustic-state'),
		'section'    => 'RS_fonts-section',
		'settings'   => 'Font_primary_name',
		'description' => esc_html__('Example: "Inconsolata"', 'rustic-state'),
	));

	//  Serif
	$wp_customize->add_setting('Font_secondary_url', array(
		'default'    => 'https://fonts.googleapis.com/css?family=IM+Fell+DW+Pica:400,400i',
		'capability' => 'edit_theme_options',
		'type'       => 'option',
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control('Font_secondary_url', array(
		'label'      => esc_html__('The header font URL', 'rustic-state'),
		'section'    => 'RS_fonts-section',
		'settings'   => 'Font_secondary_url',
		'description' => esc_html__('Example: "https://fonts.googleapis.com/css?family=IM+Fell+DW+Pica:400,400i"', 'rustic-state'),
	));

	$wp_customize->add_setting('Font_secondary_name', array(
		'default'    => 'IM Fell DW Pica',
		'capability' => 'edit_theme_options',
		'type'       => 'option',
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control('Font_secondary_name', array(
		'label'      => esc_html__('The header font family name', 'rustic-state'),
		'section'    => 'RS_fonts-section',
		'settings'   => 'Font_secondary_name',
		'description' => esc_html__('Example: "IM Fell DW Pica"', 'rustic-state'),
	));


	//  =============================
	//  = Theme colors
	//  =============================

	//  Menu links
	 $wp_customize->add_setting('RS_colors_menu', array(
	   'default'    => '',
	   'capability' => 'edit_theme_options',
	   'type'       => 'option',
	   'sanitize_callback' => 'sanitize_hex_color',
	 ));
	 $wp_customize->add_control( new WP_Customize_Color_Control($wp_customize, 'RS_colors_menu', array(
	   'label'    => esc_html__('Menu links color', 'rustic-state'),
	   'section'  => 'colors',
		 'description' => esc_html__('Color of the links in main menu', 'rustic-state'),
	   'settings' => 'RS_colors_menu',
	 )));

	//  Menu hover links
	 $wp_customize->add_setting('RS_colors_menu_hover', array(
	   'default'    => '',
	   'capability' => 'edit_theme_options',
	   'type'       => 'option',
	   'sanitize_callback' => 'sanitize_hex_color',
	 ));
	 $wp_customize->add_control( new WP_Customize_Color_Control($wp_customize, 'RS_colors_menu_hover', array(
	   'label'    => esc_html__('Menu links hover color', 'rustic-state'),
	   'section'  => 'colors',
	   'settings' => 'RS_colors_menu_hover',
		 'description' => esc_html__('Color of the hover links in main menu', 'rustic-state'),
	 )));

	 	//  Links color
	 $wp_customize->add_setting('RS_colors_link', array(
	   'default'    => '',
	   'capability' => 'edit_theme_options',
	   'type'       => 'option',
	   'sanitize_callback' => 'sanitize_hex_color',
	 ));
	 $wp_customize->add_control( new WP_Customize_Color_Control($wp_customize, 'RS_colors_link', array(
	   'label'    => esc_html__('Links color', 'rustic-state'),
	   'section'  => 'colors',
	   'settings' => 'RS_colors_link',
		 'description' => esc_html__('Color of the links in your articles', 'rustic-state'),
	 )));

	 	//  Links hover color
	 $wp_customize->add_setting('RS_colors_link_hover', array(
	   'default'    => '',
	   'capability' => 'edit_theme_options',
	   'type'       => 'option',
	   'sanitize_callback' => 'sanitize_hex_color',
	 ));
	 $wp_customize->add_control( new WP_Customize_Color_Control($wp_customize, 'RS_colors_link_hover', array(
	   'label'    => esc_html__('Links hover color', 'rustic-state'),
	   'section'  => 'colors',
	   'settings' => 'RS_colors_link_hover',
		 'description' => esc_html__('Color of the hover links in your articles', 'rustic-state'),
	 )));

	 //  Buttons color
	 $wp_customize->add_setting('RS_colors_btn', array(
	   'default'    => '',
	   'capability' => 'edit_theme_options',
	   'type'       => 'option',
	   'sanitize_callback' => 'sanitize_hex_color',
	 ));
	 $wp_customize->add_control( new WP_Customize_Color_Control($wp_customize, 'RS_colors_btn', array(
	   'label'    => esc_html__('Buttons color', 'rustic-state'),
	   'section'  => 'colors',
	   'settings' => 'RS_colors_btn',
		 'description' => esc_html__('Color of your buttons background', 'rustic-state'),
	 )));

	 //  Buttons hover color
	 $wp_customize->add_setting('RS_colors_btn_hover', array(
	   'default'    => '',
	   'capability' => 'edit_theme_options',
	   'type'       => 'option',
	   'sanitize_callback' => 'sanitize_hex_color',
	 ));
	 $wp_customize->add_control( new WP_Customize_Color_Control($wp_customize, 'RS_colors_btn_hover', array(
	   'label'    => esc_html__('Buttons hover color', 'rustic-state'),
	   'section'  => 'colors',
	   'settings' => 'RS_colors_btn_hover',
		 'description' => esc_html__('Hover color of your buttons background', 'rustic-state'),
	 )));


	 //  Text color
	 $wp_customize->add_setting('RS_colors_text', array(
	   'default'    => '',
	   'capability' => 'edit_theme_options',
	   'type'       => 'option',
	   'sanitize_callback' => 'sanitize_hex_color',
	 ));
	 $wp_customize->add_control( new WP_Customize_Color_Control($wp_customize, 'RS_colors_text', array(
	   'label'    => esc_html__('The text color', 'rustic-state'),
		 'description' => esc_html__('Color of the text in the post', 'rustic-state'),
	   'section'  => 'colors',
	   'settings' => 'RS_colors_text',
	 )));

	 //  Header post color
	 $wp_customize->add_setting('RS_colors_post_header', array(
	   'default'    => '',
	   'capability' => 'edit_theme_options',
	   'type'       => 'option',
	   'sanitize_callback' => 'sanitize_hex_color',
	 ));
	 $wp_customize->add_control( new WP_Customize_Color_Control($wp_customize, 'RS_colors_post_header', array(
	   'label'    => esc_html__('The header color in the post', 'rustic-state'),
		 'description' => esc_html__('Color of the header in the post', 'rustic-state'),
	   'section'  => 'colors',
	   'settings' => 'RS_colors_post_header',
	 )));

	 //  =============================
	 //  = Feature boxes
	 //  =============================
	 $wp_customize->add_section('RS_feature_box', array(
 		 'title'   	 		=> esc_html__('Features', 'rustic-state'),
 		 'description' 	=> '',
 		 'priority'  		=> 0,
 	 ));

	 //  Enable Features
 	 $wp_customize->add_setting('RS_feature_box_enable', array(
 	   'capability' => 'edit_theme_options',
		 'default'    => true,
		 'type'       => 'option',
 	   'sanitize_callback' => 'sanitize_text_field',
 	 ));
 	 $wp_customize->add_control('RS_feature_box_enable', array(
 	   'label'      => esc_html__('Enable the featured boxes', 'rustic-state'),
 	   'section'    => 'RS_feature_box',
		 'type'       => 'checkbox',
 	   'settings'   => 'RS_feature_box_enable',
 	 ));


	 //  BOX 1
 	 $wp_customize->add_setting('RS_box1-title', array(
 	   'default'    => '',
 	   'capability' => 'edit_theme_options',
 	   'type'       => 'option',
 	   'sanitize_callback' => 'sanitize_text_field',
 	 ));
 	 $wp_customize->add_control('RS_box1-title', array(
 	   'label'      => esc_html__('Box 1 - button title', 'rustic-state'),
 	   'section'    => 'RS_feature_box',
 	   'settings'   => 'RS_box1-title',
 		 'description' => esc_html__('Description which appears in the first box', 'rustic-state'),
 	 ));

 	 $wp_customize->add_setting('RS_box1-url', array(
 	   'default'    => '',
 	   'capability' => 'edit_theme_options',
 	   'type'       => 'option',
 	   'sanitize_callback' => 'sanitize_text_field',
 	 ));
 	 $wp_customize->add_control('RS_box1-url', array(
 	   'label'      => esc_html__('Box 1 - url', 'rustic-state'),
 	   'section'    => 'RS_feature_box',
 	   'settings'   => 'RS_box1-url',
 		 'description' => esc_html__('URL address which appears in the first box', 'rustic-state'),
 	 ));

 	 $wp_customize->add_setting('RS_box1-img', array(
 	   'default'    => '',
 	   'capability' => 'edit_theme_options',
 	   'type'       => 'option',
 	   'sanitize_callback' => 'esc_url_raw'
 	 ));
 	 $wp_customize->add_control( new WP_Customize_Image_Control($wp_customize, 'RS_box1-img', array(
 	   'label'    => esc_html__('Box 1 - background', 'rustic-state'),
 	   'section'  => 'RS_feature_box',
 	   'settings' => 'RS_box1-img',
 		 'description' => esc_html__('Image which appears in the first box', 'rustic-state'),
 	 )));

	$wp_customize->add_setting('RS_box1-color', array(
		'default'    => '',
		'capability' => 'edit_theme_options',
		'type'       => 'option',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control( new WP_Customize_Color_Control($wp_customize, 'RS_box1-color', array(
		'label'    => esc_html__('Box 1 - button color', 'rustic-state'),
		'description' => esc_html__('Color of the button in the first box', 'rustic-state'),
		'section'  => 'RS_feature_box',
		'settings' => 'RS_box1-color',
	)));

	$wp_customize->add_setting('RS_box1-header', array(
		'default'    => '',
		'capability' => 'edit_theme_options',
		'type'       => 'option',
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control('RS_box1-header', array(
		'label'      => esc_html__('Box 1 - header', 'rustic-state'),
		'section'    => 'RS_feature_box',
		'settings'   => 'RS_box1-header',
		'description' => esc_html__('Header which appears in the first box', 'rustic-state'),
	));

	$wp_customize->add_setting('RS_box1-header-color', array(
		'default'    => '',
		'capability' => 'edit_theme_options',
		'type'       => 'option',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control( new WP_Customize_Color_Control($wp_customize, 'RS_box1-header-color', array(
		'label'    => esc_html__('Box 1 - header color', 'rustic-state'),
		'description' => esc_html__('Color of the header in the first box', 'rustic-state'),
		'section'  => 'RS_feature_box',
		'settings' => 'RS_box1-header-color',
	)));

	//  BOX 2
	$wp_customize->add_setting('RS_box2-title', array(
		'default'    => '',
		'capability' => 'edit_theme_options',
		'type'       => 'option',
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control('RS_box2-title', array(
		'label'      => esc_html__('Box 2 - button title', 'rustic-state'),
		'section'    => 'RS_feature_box',
		'settings'   => 'RS_box2-title',
		'description' => esc_html__('Description which appears in the second box', 'rustic-state'),
	));

	$wp_customize->add_setting('RS_box2-url', array(
		'default'    => '',
		'capability' => 'edit_theme_options',
		'type'       => 'option',
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control('RS_box2-url', array(
		'label'      => esc_html__('Box 2 - url', 'rustic-state'),
		'section'    => 'RS_feature_box',
		'settings'   => 'RS_box2-url',
		'description' => esc_html__('URL address which appears in the second box', 'rustic-state'),
	));

	$wp_customize->add_setting('RS_box2-img', array(
		'default'    => '',
		'capability' => 'edit_theme_options',
		'type'       => 'option',
		'sanitize_callback' => 'esc_url_raw'
	));
	$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize, 'RS_box2-img', array(
		'label'    => esc_html__('Box 2 - background', 'rustic-state'),
		'section'  => 'RS_feature_box',
		'settings' => 'RS_box2-img',
		'description' => esc_html__('Image which appears in the second box', 'rustic-state'),
	)));

	$wp_customize->add_setting('RS_box2-color', array(
	 'default'    => '',
	 'capability' => 'edit_theme_options',
	 'type'       => 'option',
	 'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control( new WP_Customize_Color_Control($wp_customize, 'RS_box2-color', array(
	 'label'    => esc_html__('Box 2 - button color', 'rustic-state'),
	 'description' => esc_html__('Color of the button in the second box', 'rustic-state'),
	 'section'  => 'RS_feature_box',
	 'settings' => 'RS_box2-color',
	)));

	$wp_customize->add_setting('RS_box2-header', array(
		'default'    => '',
		'capability' => 'edit_theme_options',
		'type'       => 'option',
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control('RS_box2-header', array(
		'label'      => esc_html__('Box 2 - header', 'rustic-state'),
		'section'    => 'RS_feature_box',
		'settings'   => 'RS_box2-header',
		'description' => esc_html__('Header which appears in the first box', 'rustic-state'),
	));

	$wp_customize->add_setting('RS_box2-header-color', array(
		'default'    => '',
		'capability' => 'edit_theme_options',
		'type'       => 'option',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control( new WP_Customize_Color_Control($wp_customize, 'RS_box2-header-color', array(
		'label'    => esc_html__('Box 2 - header color', 'rustic-state'),
		'description' => esc_html__('Color of the header in the first box', 'rustic-state'),
		'section'  => 'RS_feature_box',
		'settings' => 'RS_box2-header-color',
	)));

	//  BOX 3
	$wp_customize->add_setting('RS_box3-title', array(
		'default'    => '',
		'capability' => 'edit_theme_options',
		'type'       => 'option',
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control('RS_box3-title', array(
		'label'      => esc_html__('Box 3 - button title', 'rustic-state'),
		'section'    => 'RS_feature_box',
		'settings'   => 'RS_box3-title',
		'description' => esc_html__('Description which appears in the third box', 'rustic-state'),
	));

	$wp_customize->add_setting('RS_box3-url', array(
		'default'    => '',
		'capability' => 'edit_theme_options',
		'type'       => 'option',
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control('RS_box3-url', array(
		'label'      => esc_html__('Box 3 - url', 'rustic-state'),
		'section'    => 'RS_feature_box',
		'settings'   => 'RS_box3-url',
		'description' => esc_html__('URL address which appears in the third box', 'rustic-state'),
	));

	$wp_customize->add_setting('RS_box3-img', array(
		'default'    => '',
		'capability' => 'edit_theme_options',
		'type'       => 'option',
		'sanitize_callback' => 'esc_url_raw'
	));
	$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize, 'RS_box3-img', array(
		'label'    => esc_html__('Box 3 - background', 'rustic-state'),
		'section'  => 'RS_feature_box',
		'settings' => 'RS_box3-img',
		'description' => esc_html__('Image which appears in the third box', 'rustic-state'),
	)));

	$wp_customize->add_setting('RS_box3-color', array(
	 'default'    => '',
	 'capability' => 'edit_theme_options',
	 'type'       => 'option',
	 'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control( new WP_Customize_Color_Control($wp_customize, 'RS_box3-color', array(
	 'label'    => esc_html__('Box 3 - button color', 'rustic-state'),
	 'description' => esc_html__('Color of the button in the third box', 'rustic-state'),
	 'section'  => 'RS_feature_box',
	 'settings' => 'RS_box3-color',
	)));

	$wp_customize->add_setting('RS_box3-header', array(
		'default'    => '',
		'capability' => 'edit_theme_options',
		'type'       => 'option',
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control('RS_box3-header', array(
		'label'      => esc_html__('Box 3 - header', 'rustic-state'),
		'section'    => 'RS_feature_box',
		'settings'   => 'RS_box3-header',
		'description' => esc_html__('Header which appears in the first box', 'rustic-state'),
	));

	$wp_customize->add_setting('RS_box3-header-color', array(
		'default'    => '',
		'capability' => 'edit_theme_options',
		'type'       => 'option',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control( new WP_Customize_Color_Control($wp_customize, 'RS_box3-header-color', array(
		'label'    => esc_html__('Box 3 - header color', 'rustic-state'),
		'description' => esc_html__('Color of the header in the first box', 'rustic-state'),
		'section'  => 'RS_feature_box',
		'settings' => 'RS_box3-header-color',
	)));


	//  =============================
	//  = User profil
	//  =============================
	$wp_customize->add_section('RS_profil_section', array(
		 'title'   	 		=> esc_html__('Profile image', 'rustic-state'),
		 'description' 	=> '',
		 'priority'  		=> 0,
	 ));

	 $wp_customize->add_setting('RS_profil', array(
	   'default'    => esc_html__("Hey there! It's Annie Anderson behind Rustic State Blog. I'm always happy to hear from you. Just update this info via WordPress admin panel.", 'rustic-state'),
	   'capability' => 'edit_theme_options',
	   'type'       => 'option',
	   'sanitize_callback' => 'sanitize_text_field',
	 ));
	 $wp_customize->add_control('RS_profil-1', array(
	   'label'      => esc_html__('Profile description', 'rustic-state'),
	   'section'    => 'RS_profil_section',
	   'settings'   => 'RS_profil',
		 'description' => esc_html__('Description which appears in the sidebar section and in the footer', 'rustic-state'),
	 ));

	 $wp_customize->add_setting('RS_profil-upload', array(
	   'default'    => '',
	   'capability' => 'edit_theme_options',
	   'type'       => 'option',
	   'sanitize_callback' => 'esc_url_raw'
	 ));
	 $wp_customize->add_control( new WP_Customize_Image_Control($wp_customize, 'RS_profil-upload', array(
	   'label'    => esc_html__('Profile image upload', 'rustic-state'),
	   'section'  => 'RS_profil_section',
	   'settings' => 'RS_profil-upload',
		 'description' => esc_html__('Image which appears in the sidebar section', 'rustic-state'),
	 )));
}
add_action( 'customize_register', 'rustic_state_customize_register' );


/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function rustic_state_sidebar_social_register( $wp_customize ) {

	//  =============================
  //  = Boxes section
  //  =============================
	$wp_customize->add_section('RS_social', array(
		 'title'   	 		=> esc_html__('Social Icons URLs', 'rustic-state'),
		 'description' 	=> '',
		 'priority'  		=> 1,
	 ));

	 //  =============================
   //  = Facebook
   //  =============================
	$wp_customize->add_setting('RS_social-facebook', array(
    'capability' => 'edit_theme_options',
    'type'       => 'option',
		'default'    => '#',
		'sanitize_callback' => 'esc_url_raw',
  ));
	$wp_customize->add_control('RS_social-facebook', array(
    'label'      => esc_html__('Facebook', 'rustic-state'),
    'section'    => 'RS_social',
    'settings'   => 'RS_social-facebook'
  ));
	 //  =============================
   //  = Twitter
   //  =============================
	$wp_customize->add_setting('RS_social-twitter', array(
    'capability' => 'edit_theme_options',
    'type'       => 'option',
		'default'    => '#',
		'sanitize_callback' => 'esc_url_raw',
  ));
	$wp_customize->add_control('RS_social-twitter', array(
    'label'      => esc_html__('Twitter', 'rustic-state'),
    'section'    => 'RS_social',
    'settings'   => 'RS_social-twitter'
  ));
	 //  =============================
   //  = Google
   //  =============================
	$wp_customize->add_setting('RS_social-google', array(
    'capability' => 'edit_theme_options',
    'type'       => 'option',
		'default'    => '#',
		'sanitize_callback' => 'esc_url_raw',
  ));
	$wp_customize->add_control('RS_social-google', array(
    'label'      => esc_html__('Google', 'rustic-state'),
    'section'    => 'RS_social',
    'settings'   => 'RS_social-google'
  ));
	 //  =============================
   //  = Pinterest
   //  =============================
	$wp_customize->add_setting('RS_social-pinterest', array(
    'capability' => 'edit_theme_options',
    'type'       => 'option',
		'default'    => '#',
		'sanitize_callback' => 'esc_url_raw',
  ));
	$wp_customize->add_control('RS_social-pinterest', array(
    'label'      => esc_html__('Pinterest', 'rustic-state'),
    'section'    => 'RS_social',
    'settings'   => 'RS_social-pinterest'
  ));
	 //  =============================
   //  = Instagram
   //  =============================
	$wp_customize->add_setting('RS_social-instagram', array(
    'capability' => 'edit_theme_options',
    'type'       => 'option',
		'default'    => '#',
		'sanitize_callback' => 'esc_url_raw',
  ));
	$wp_customize->add_control('RS_social-instagram', array(
    'label'      => esc_html__('Instagram', 'rustic-state'),
    'section'    => 'RS_social',
    'settings'   => 'RS_social-instagram'
  ));
	 //  =============================
   //  = Youtube
   //  =============================
	$wp_customize->add_setting('RS_social-youtube', array(
    'capability' => 'edit_theme_options',
    'type'       => 'option',
		'default'    => '#',
		'sanitize_callback' => 'esc_url_raw',
  ));
	$wp_customize->add_control('RS_social-youtube', array(
    'label'      => esc_html__('Youtube', 'rustic-state'),
    'section'    => 'RS_social',
    'settings'   => 'RS_social-youtube'
  ));

}
add_action( 'customize_register', 'rustic_state_sidebar_social_register' );
