<?php
/*
Plugin Name: Popular categories
Version: 1.0
Plugin URI: http://www.eppearance.pl/
Description: Display recent posts with thumbnail and date
Author: Paweł Stachula
Author URI: http://www.eppearance.pl/T
*/

class Rustic_State_Popular_posts_widget extends WP_Widget
{
  public function __construct()
  {
    $widget_ops = array(
      'classname' => 'Rustic_State_Popular_posts_widget',
      'description' => 'Popular posts with thumbnail.'
    );
    parent::__construct('Rustic_State_Popular_posts_widget', '[ RS ] Popular posts', $widget_ops);
  }

  public function form($instance)
  {
    $instance = wp_parse_args( (array) $instance, array(
      'title' => '',
      'number' => '5'
    ) );
    $title = $instance['title'];
    $number = $instance['number'];
    ?>
      <p>
        <label for="<?php echo esc_html($this->get_field_id('title')); ?>"><?php echo esc_html__('Title:', 'rustic-state') ?></label>
        <input class="widefat" id="<?php echo esc_html($this->get_field_id('title')); ?>" name="<?php echo esc_html($this->get_field_name('title')); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
      </p>
      <p>
        <label for="<?php echo esc_html($this->get_field_id('number')); ?>"><?php echo esc_html__('Number of posts:', 'rustic-state') ?></label>
        <input type="number" class="tiny-text" id="<?php echo esc_html($this->get_field_id('number')); ?>" name="<?php echo esc_html($this->get_field_name('number')); ?>"  value="<?php echo esc_attr($number); ?>" />
      </p>
    <?php
  }

  public function update($new_instance, $old_instance)
  {
    $instance = $old_instance;
    $instance['title'] = esc_html($new_instance['title']);
    $instance['number'] = esc_html($new_instance['number']);
    return $instance;
  }

  public function widget($args, $instance)
  {
    extract($args, EXTR_SKIP);
    echo $before_widget;

    $title = empty($instance['title']) ? esc_html__('Popular posts', 'rustic-state') : apply_filters('widget_title', $instance['title']);

    echo $before_title;
    echo $title;
    echo $after_title;
    ?>

    <?php $latestPosts = new WP_Query( array(
      'posts_per_page' => $instance['number'],
      'post__not_in' => get_option('sticky_posts'),
      'meta_key' => 'rustic_state_post_views_count',
      'orderby' => 'meta_value_num',
      'order' => 'DESC'
    )); ?>

    <div class="recent-posts">
      <?php if ( $latestPosts->have_posts() ) : ?>
        <?php while ( $latestPosts->have_posts() ) : $latestPosts->the_post(); ?>
          <div class="single">

              <?php if(has_post_thumbnail()): ?>
                <div class="single-left">
                  <img src="<?php the_post_thumbnail_url('thumbnail') ?>" alt="<?php echo the_title() ?>">
                </div>
              <?php endif ?>

              <div class="single-right">
                <a class="content" href="<?php the_permalink() ?>"><?php echo esc_html(wp_strip_all_tags(mb_strimwidth(get_the_content(), 0, 50, '...'))) ?></a>
                <div class="post-date">
                  <?php echo esc_html(get_the_date()); ?>
                </div>
              </div>
          </div>
        <?php endwhile; ?>
      <?php endif; ?>
      <?php wp_reset_postdata(); ?>
    </div>

    <?php
    echo $after_widget;
  }
}

function Rustic_State_Popular_posts_widget_init() {
	register_widget( 'Rustic_State_Popular_posts_widget' );
}

add_action( 'widgets_init', 'Rustic_State_Popular_posts_widget_init');
