<?php
/**
	* Plugin Name: Simple Slick Slider
	* Description: A plugin to create a custom post type for Slider
	* Version:  1.2
	* Author: Eppearance
	* Author URI:eppearance.pl
	* License:  GPL2
*/


function slider_post_type() {
	$labels = array(
		'name'                  => _x( 'Slider', 'Post Type General Name', 'simple-slick-slider' ),
		'singular_name'         => _x( 'Slider', 'Post Type Singular Name', 'simple-slick-slider' ),
		'menu_name'             => __( 'Simple Slider', 'simple-slick-slider' ),
		'name_admin_bar'        => __( 'Slider', 'simple-slick-slider' ),
		'archives'              => __( 'Item Archives', 'simple-slick-slider' ),
		'attributes'            => __( 'Item Attributes', 'simple-slick-slider' ),
		'parent_item_colon'     => __( 'Parent Item:', 'simple-slick-slider' ),
		'all_items'             => __( 'All Items', 'simple-slick-slider' ),
		'add_new_item'          => __( 'Add New Item', 'simple-slick-slider' ),
		'add_new'               => __( 'Add New', 'simple-slick-slider' ),
		'new_item'              => __( 'New Item', 'simple-slick-slider' ),
		'edit_item'             => __( 'Edit Item', 'simple-slick-slider' ),
		'update_item'           => __( 'Update Item', 'simple-slick-slider' ),
		'view_item'             => __( 'View Item', 'simple-slick-slider' ),
		'view_items'            => __( 'View Items', 'simple-slick-slider' ),
		'search_items'          => __( 'Search Item', 'simple-slick-slider' ),
		'not_found'             => __( 'Not found', 'simple-slick-slider' ),
		'not_found_in_trash'    => __( 'Not found in Trash', 'simple-slick-slider' ),
		'featured_image'        => __( 'Featured Image', 'simple-slick-slider' ),
		'set_featured_image'    => __( 'Set featured image', 'simple-slick-slider' ),
		'remove_featured_image' => __( 'Remove featured image', 'simple-slick-slider' ),
		'use_featured_image'    => __( 'Use as featured image', 'simple-slick-slider' ),
		'insert_into_item'      => __( 'Insert into item', 'simple-slick-slider' ),
		'uploaded_to_this_item' => __( 'Uploaded to this item', 'simple-slick-slider' ),
		'items_list'            => __( 'Items list', 'simple-slick-slider' ),
		'items_list_navigation' => __( 'Items list navigation', 'simple-slick-slider' ),
		'filter_items_list'     => __( 'Filter items list', 'simple-slick-slider' ),
	);
	$args = array(
		'label'                 => __( 'Slider', 'simple-slick-slider' ),
		'description'           => __( 'Slider', 'simple-slick-slider' ),
		'labels'                => $labels,
		'supports'              => array( 'title', 'thumbnail',  '', ),
		'taxonomies'            => array( 'category' ),
		'hierarchical'          => false,
		'public'                => true,
		'show_ui'               => true,
		'show_in_menu'          => true,
		'menu_position'         => 5,
		'show_in_admin_bar'     => true,
		'show_in_nav_menus'     => true,
		'can_export'            => true,
		'has_archive'           => true,
		'exclude_from_search'   => false,
		'publicly_queryable'    => true,
		'capability_type'       => 'page',
    'menu_icon'             => 'dashicons-format-image',
    'register_meta_box_cb' => 'add_slide_url_metabox'
	);
	register_post_type( 'slider_type', $args );

}
add_action( 'init', 'slider_post_type', 0 );

// Add the Events Meta Boxes
function add_slide_url_metabox() {
	add_meta_box('slide-url-metabox', 'Slide Options', 'slide_url_metabox_markup', 'slider_type', 'side', 'high', null);
}
add_action("add_meta_boxes", "add_slide_url_metabox");

function slide_url_metabox_markup($object) {
	wp_nonce_field(basename(__FILE__), "meta-box-nonce");
?>
	<div>
		<label for="slide_desc">Slide Description</label><br>
		<input name="slide_desc" type="text" value="<?php echo get_post_meta($object->ID, "slide_desc", true); ?>">
	</div>
	<br>
  <div>
    <label for="slide_url">Slide URL</label><br>
    <input name="slide_url" type="text" value="<?php echo get_post_meta($object->ID, "slide_url", true); ?>">
  </div>
<?php
}

function save_custom_meta_box($post_id, $post, $update) {
  $slug = "slider_type";
  $meta_url = "";
  $slide_desc = "";

  if (!isset($_POST["meta-box-nonce"]) || !wp_verify_nonce($_POST["meta-box-nonce"], basename(__FILE__))) return $post_id;
  if(!current_user_can("edit_post", $post_id)) return $post_id;
  if(defined("DOING_AUTOSAVE") && DOING_AUTOSAVE) return $post_id;
  if($slug != $post->post_type) return $post_id;

  if(isset($_POST["slide_url"])) {
    $meta_url = $_POST["slide_url"];
		update_post_meta($post_id, "slide_url", $meta_url);
  }
  if(isset($_POST["slide_desc"])) {
    $slide_desc = $_POST["slide_desc"];
		update_post_meta($post_id, "slide_desc", $slide_desc);
  }
}

add_action("save_post", "save_custom_meta_box", 10, 3);


/**
* Proper way to enqueue scripts and styles.
*/
function simple_slick_slider_scripts_loader() {
	wp_enqueue_style( 'slick-css', plugin_dir_url( __FILE__ ) . 'assets/jquery.slick/jquery.slick.css' );
	wp_enqueue_style( 'simple-slick-slider-css-styles', plugin_dir_url( __FILE__ ) . 'assets/styles.css' );

	wp_enqueue_script( 'simple-slick-slider-main', plugin_dir_url( __FILE__ ) . 'assets/jquery.slick/jquery.slick.js', array('jquery'), '1.0.0', true );
}
add_action( 'wp_enqueue_scripts', 'simple_slick_slider_scripts_loader' );

/**
* Loads the settings page and short codes
*/
require_once dirname( __FILE__ ) . '/inc/short_code.php';
require_once dirname( __FILE__ ) . '/inc/options_page.php';
